pub enum Error {
InvalidEvent(u32),
InvalidRangedEvent {
event: u32,
min: u32,
max: u32,
},
InvalidConfig(Config),
Installation,
Threadpool(ThreadPoolBuildError),
Uninstallation,
EventLoop(Error),
AlreadyUninstalled,
}Expand description
win_event_hook library error type.
Variants
InvalidEvent(u32)
Indicates an event with a given id is not known.
InvalidRangedEvent
Indicates an event with a given id falls outside the configured range.
InvalidConfig(Config)
Indicates a config instance was determined to be invalid.
Installation
Indicates an installation failure. See Microsoft Documentation for more information.
Threadpool(ThreadPoolBuildError)
Indicates an installation failure due to an underlying threadpool issue.
Uninstallation
Indicates an uninstallation failure. See Microsoft Documentation for more information.
EventLoop(Error)
Indicates an uninstallation failure due to an underlying event loop issue.
AlreadyUninstalled
Indicates an uninstallation failure due to the hook already being uninstalled.